==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/reconciliationreport/reconciliationreport.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sl]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx",
                "Name[zh_CN]": "Cristian Oneț"
            }
        ],
        "Description": "Creates a report after each reconciliation containing data about the reconciliation process",
        "Description[ca@valencia]": "Crea un informe després de cada conciliació que conté dades del procés de conciliació",
        "Description[ca]": "Crea un informe després de cada conciliació que conté dades del procés de conciliació",
        "Description[de]": "Erstellt nach jedem Abgleich einen Bericht, der Daten über den Abgleich-Prozess enthält",
        "Description[en_GB]": "Creates a report after each reconciliation containing data about the reconciliation process",
        "Description[es]": "Crea un informe tras cada reconciliación que contenga datos sobre el proceso de reconciliación",
        "Description[et]": "Aruande loomine pärast iga kooskõlastamist, kaasates kooskõlastamise andmed",
        "Description[eu]": "Berdinkatze prozesuaren informazioa duen txostena sortzen du berdinkatze bakoitzaren ondoren",
        "Description[fi]": "Luo raportin jokaisen täsmäytyksen jälkeen sisältäen tietoja täsmäytysprosessista",
        "Description[fr]": "Crée un rapport après chaque consolidation contenant des données sur le processus de consolidation",
        "Description[gl]": "Crea un informe tras cada reconciliación que conteña datos sobre o proceso de reconciliación",
        "Description[it]": "Crea un report dopo ogni riconciliazione che contiene dati sul processo di riconciliazione",
        "Description[ko]": "각각 조정 이후 조정 절차 정보가 있는 보고서를 생성합니다",
        "Description[nl]": "Maakt een rapport aan na elke transactiecontrole met gegevens over het controleproces",
        "Description[pl]": "Tworzy sprawozdanie, po każdym uzgodnieniu, zawierające dane o procesie uzgadniania",
        "Description[pt]": "Cria um relatório após cada reconciliação de contas, contendo os dados sobre o processo de reconciliação",
        "Description[pt_BR]": "Cria um relatório após cada reconciliação contendo dados sobre o processo de reconciliação",
        "Description[sk]": "Vytvorí report po každom zrovnaní obsahujúcom dáta o procese zrovnania",
        "Description[sl]": "Po vsaki uskladitvi ustvari poročilo, ki vsebuje podatke o postopku usklajevanja",
        "Description[sv]": "Skapar en rapport efter varje avstämning som innehåller information om avstämningsprocessen",
        "Description[uk]": "Створення звітів після кожного узгодження із даними щодо процедури узгодження",
        "Description[x-test]": "xxCreates a report after each reconciliation containing data about the reconciliation processxx",
        "Description[zh_CN]": "每次对账后生成包含对账过程数据的报表",
        "EnabledByDefault": true,
        "Icon": "application-vnd.oasis.opendocument.spreadsheet",
        "Id": "reconciliationreport",
        "License": "GPL",
        "Name": "Reconciliation report",
        "Name[ca@valencia]": "Informe de conciliació",
        "Name[ca]": "Informe de conciliació",
        "Name[cs]": "Hlášení rozvahy",
        "Name[de]": "Abgleichbericht",
        "Name[en_GB]": "Reconciliation report",
        "Name[es]": "Informe de reconciliación",
        "Name[et]": "Kooskõlastamisaruanne",
        "Name[eu]": "Berdinkatze-txostena",
        "Name[fi]": "Täsmäytysraportti",
        "Name[fr]": "Rapport de consolidation",
        "Name[gl]": "Informe de conciliación",
        "Name[it]": "Report di riconciliazione",
        "Name[ko]": "조정 보고서",
        "Name[nl]": "Rapport over transactiecontrole",
        "Name[pl]": "Sprawozdanie uzgadniania",
        "Name[pt]": "Relatório de reconciliação",
        "Name[pt_BR]": "Relatório de reconciliação",
        "Name[ru]": "Отчёт по сверке",
        "Name[sk]": "Zrovnávacia správa",
        "Name[sl]": "Poročilo o uskladitvi",
        "Name[sv]": "Avstämningsrapport",
        "Name[uk]": "Звіт щодо звірки",
        "Name[x-test]": "xxReconciliation reportxx",
        "Name[zh_CN]": "对帐报告",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.3.orig.tar.xz: kmymoney-5.1.3/kmymoney/plugins/reconciliationreport/reconciliationreport.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "onet.cristian@gmail.com",
                "Name": "Cristian Oneț",
                "Name[ca@valencia]": "Cristian Oneț",
                "Name[ca]": "Cristian Oneț",
                "Name[cs]": "Cristian Oneț",
                "Name[de]": "Cristian Oneț",
                "Name[en_GB]": "Cristian Oneț",
                "Name[es]": "Cristian Oneț",
                "Name[et]": "Cristian Oneț",
                "Name[eu]": "Cristian Oneț",
                "Name[fi]": "Cristian Oneț",
                "Name[fr]": "Cristian Oneț",
                "Name[gl]": "Cristian Oneț",
                "Name[ia]": "Cristian Oneț",
                "Name[it]": "Cristian Oneț",
                "Name[ko]": "Cristian Oneț",
                "Name[nl]": "Cristian Oneț",
                "Name[pl]": "Cristian Oneț",
                "Name[pt]": "Cristian Oneț",
                "Name[pt_BR]": "Cristian Oneț",
                "Name[ru]": "Cristian Oneț",
                "Name[sk]": "Cristian Oneț",
                "Name[sl]": "Cristian Oneț",
                "Name[sv]": "Cristian Oneț",
                "Name[uk]": "Cristian Oneț",
                "Name[x-test]": "xxCristian Onețxx",
                "Name[zh_CN]": "Cristian Oneț"
            }
        ],
        "Description": "Creates a report after each reconciliation containing data about the reconciliation process",
        "Description[ca@valencia]": "Crea un informe després de cada conciliació que conté dades del procés de conciliació",
        "Description[ca]": "Crea un informe després de cada conciliació que conté dades del procés de conciliació",
        "Description[de]": "Erstellt nach jedem Abgleich einen Bericht, der Daten über den Abgleich-Prozess enthält",
        "Description[en_GB]": "Creates a report after each reconciliation containing data about the reconciliation process",
        "Description[es]": "Crea un informe tras cada reconciliación que contenga datos sobre el proceso de reconciliación",
        "Description[et]": "Aruande loomine pärast iga kooskõlastamist, kaasates kooskõlastamise andmed",
        "Description[eu]": "Berdinkatze prozesuaren informazioa duen txostena sortzen du berdinkatze bakoitzaren ondoren",
        "Description[fi]": "Luo raportin jokaisen täsmäytyksen jälkeen sisältäen tietoja täsmäytysprosessista",
        "Description[fr]": "Crée un rapport après chaque consolidation contenant des données sur le processus de consolidation",
        "Description[gl]": "Crea un informe tras cada reconciliación que conteña datos sobre o proceso de reconciliación",
        "Description[it]": "Crea un report dopo ogni riconciliazione che contiene dati sul processo di riconciliazione",
        "Description[ko]": "각각 조정 이후 조정 절차 정보가 있는 보고서를 생성합니다",
        "Description[nl]": "Maakt een rapport aan na elke transactiecontrole met gegevens over het controleproces",
        "Description[pl]": "Tworzy sprawozdanie, po każdym uzgodnieniu, zawierające dane o procesie uzgadniania",
        "Description[pt]": "Cria um relatório após cada reconciliação de contas, contendo os dados sobre o processo de reconciliação",
        "Description[pt_BR]": "Cria um relatório após cada reconciliação contendo dados sobre o processo de reconciliação",
        "Description[ru]": "Создаёт после каждой сверки отчёт, содержащий данные о процессе сверки",
        "Description[sk]": "Vytvorí report po každom zrovnaní obsahujúcom dáta o procese zrovnania",
        "Description[sl]": "Po vsaki uskladitvi ustvari poročilo, ki vsebuje podatke o postopku usklajevanja",
        "Description[sv]": "Skapar en rapport efter varje avstämning som innehåller information om avstämningsprocessen",
        "Description[uk]": "Створення звітів після кожного узгодження із даними щодо процедури узгодження",
        "Description[x-test]": "xxCreates a report after each reconciliation containing data about the reconciliation processxx",
        "Description[zh_CN]": "每次对账后生成包含对账过程数据的报表",
        "EnabledByDefault": true,
        "Icon": "application-vnd.oasis.opendocument.spreadsheet",
        "Id": "reconciliationreport",
        "License": "GPL",
        "Name": "Reconciliation report",
        "Name[ca@valencia]": "Informe de conciliació",
        "Name[ca]": "Informe de conciliació",
        "Name[cs]": "Hlášení rozvahy",
        "Name[de]": "Abgleichbericht",
        "Name[en_GB]": "Reconciliation report",
        "Name[es]": "Informe de reconciliación",
        "Name[et]": "Kooskõlastamisaruanne",
        "Name[eu]": "Berdinkatze-txostena",
        "Name[fi]": "Täsmäytysraportti",
        "Name[fr]": "Rapport de consolidation",
        "Name[gl]": "Informe de conciliación",
        "Name[ia]": "Reporto de reconciliation",
        "Name[it]": "Report di riconciliazione",
        "Name[ko]": "조정 보고서",
        "Name[nl]": "Rapport over transactiecontrole",
        "Name[pl]": "Sprawozdanie uzgadniania",
        "Name[pt]": "Relatório de reconciliação",
        "Name[pt_BR]": "Relatório de reconciliação",
        "Name[ru]": "Отчёт по сверке",
        "Name[sk]": "Zrovnávacia správa",
        "Name[sl]": "Poročilo o uskladitvi",
        "Name[sv]": "Avstämningsrapport",
        "Name[uk]": "Звіт щодо звірки",
        "Name[x-test]": "xxReconciliation reportxx",
        "Name[zh_CN]": "对帐报告",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
